/*! 'francy-extension-jupyter, v1.1.1 - Francy - An Interactive Discrete Mathematics Framework for GAP. Renders [application/vnd.francy+json] MIME Type on Jupyter Environments, by Manuel Martins <manuelmachadomartins@gmail.com>.' */
define(["nbextensions/jupyter_francy/Vendors","base/js/namespace","nbextensions/jupyter_francy/FrancyJS","nbextensions/jupyter_francy/D3Renderer","nbextensions/jupyter_francy/GraphvizRenderer","nbextensions/jupyter_francy/index"],function(r,t,o,u,i,f){return function(r){var t={};function o(e){if(t[e]){return t[e].exports}var n=t[e]={i:e,l:false,exports:{}};r[e].call(n.exports,n,n.exports,o);n.l=true;return n.exports}o.m=r;o.c=t;o.d=function(e,n,r){if(!o.o(e,n)){Object.defineProperty(e,n,{enumerable:true,get:r})}};o.r=function(e){if(typeof Symbol!=="undefined"&&Symbol.toStringTag){Object.defineProperty(e,Symbol.toStringTag,{value:"Module"})}Object.defineProperty(e,"__esModule",{value:true})};o.t=function(n,e){if(e&1)n=o(n);if(e&8)return n;if(e&4&&typeof n==="object"&&n&&n.__esModule)return n;var r=Object.create(null);o.r(r);Object.defineProperty(r,"default",{enumerable:true,value:n});if(e&2&&typeof n!="string")for(var t in n)o.d(r,t,function(e){return n[e]}.bind(null,t));return r};o.n=function(n){var e=n&&n.__esModule?function e(){return n["default"]}:function e(){return n};o.d(e,"a",e);return e};o.o=function(e,n){return Object.prototype.hasOwnProperty.call(e,n)};o.p="";return o(o.s=1)}([function(e,n){e.exports=r},function(e,n,r){e.exports=r(2)},function(e,n,r){var t,o;if(window.require){window.require.config({map:{"*":{jupyter_francy:"nbextensions/jupyter_francy/index"}}})}Promise.resolve().then(function(){[r(0)]}).catch(r.oe);!(t=[r(3),r(0),r(4),r(5),r(6),r(7)],o=function(n,e,r,t,o,u){function i(){var e=n.notebook;u.register_renderer(n,{FrancyApp:r.FrancyApp,Logger:r.Logger,Renderers:[t.D3Renderer,o.GraphvizRenderer]},e);u.render_cells(e)}return{load_ipython_extension:i}}.apply(n,t),o!==undefined&&(e.exports=o))},function(e,n){e.exports=t},function(e,n){e.exports=o},function(e,n){e.exports=u},function(e,n){e.exports=i},function(e,n){e.exports=f}])});